@@ -25,7 +25,7 @@
 #' @param col.NR.lab color of the species labels, see see \link[graphics]{text} for more details.
 #' @param cex.NR.lab size of the species labels defautls NA for no labels, see see \link[graphics]{text} for more details.
 #' @param fac.NR.lab factor for moving the NR labels from its original coordinates for clarity, by defaults they are multiply 1.2
-#' @param leg a logical option for legend to be plotted or not, default leg=T.
+#' @param leg a logical option for legend to be plotted or not, default leg=TRUE.
 #' @param bty.leg the type of box to be drawn around the legend. The allowed values are "o" (the default) and "n", see \link[graphics]{legend} for more details.
 #' @param posi.leg setting legend positions with the following keywords "bottomright", "bottom", "bottomleft", "left", "topleft", "top", "topright", "right" and "center", see \link[graphics]{legend} for more details.
 #' @param font.sp An integer which specifies which font to use for species label. 1 corresponds to plain text (the default), 2 to bold face, 3 to italic and 4 to bold italic, see \link[graphics]{par} for more details.
@@ -37,6 +37,7 @@
 #' See \doi{10.7717/peerj.3364} for more details on the subniche concept.
 #' @examples
 #' library(subniche)
+#' library(ade4)
 #' data(doubs)
 #' dudi1 <- dudi.pca(doubs$env, scale = TRUE, scan = FALSE, nf = 3)
 #' nic1 <- niche(dudi1, doubs$fish, scann = FALSE)
@@ -51,7 +52,6 @@
 #' plot_NR(subnic1, sig=sigi$pvalue[-M], sig_thres= 0.1)
 #' @importFrom graphics par layout arrows points legend polygon abline text
 #' @importFrom wordcloud textplot
-#' @importFrom SIBER siberConvexhull
 plot_NR <- function(subnic,sig=NULL, sig_thres=0.05,
                     xlab=NULL, ylab=NULL, main=NA, col.axis="azure3", lty.axis=2, lwd.axis=2,
                     border.E="black",
@@ -66,7 +66,7 @@ plot_NR <- function(subnic,sig=NULL, sig_thres=0.05,
                     cex.NR.lab= NA,
                     fac.NR.lab=1.2,
                     col.arrow="black",  angle.arrow=20, lwd.arrow=2,
-                    length.arrow=0.1,font.sp=2, leg=T, posi.leg="topleft", bty.leg="n", ...){
+                    length.arrow=0.1,font.sp=2, leg=TRUE, posi.leg="topleft", bty.leg="n", ...){
 
   eig <- round(subnic$eig/sum(subnic$eig) * 100, 2)
   ar_sub <- subarea(subnic)
