@@ -38,7 +38,7 @@
 #' @param col.axis axis color, see \link[graphics]{par} for more details.
 #' @param lty.axis axis line type, see \link[graphics]{par} for more details.
 #' @param lwd.axis  axis width, see \link[graphics]{par} for more details.
-#' @param leg a logical option for legend to be plotted or not, default leg=T.
+#' @param leg a logical option for legend to be plotted or not, default leg=TRUE.
 #' @param bty.leg the type of box to be drawn around the legend. The allowed values are "o" (the default) and "n", see \link[graphics]{legend} for more details.
 #' @param posi.leg setting legend positions with the following keywords "bottomright", "bottom", "bottomleft", "left", "topleft", "top", "topright", "right" and "center", see \link[graphics]{legend} for more details.
 #' @param font.sp An integer which specifies which font to use for species label. 1 corresponds to plain text (the default), 2 to bold face, 3 to italic and 4 to bold italic, see \link[graphics]{par} for more details.
@@ -55,6 +55,7 @@
 #' See \doi{10.7717/peerj.3364} for more details on the subniche concept.
 #' @examples
 #' library(subniche)
+#' library(ade4)
 #' data(doubs)
 #' dudi1 <- dudi.pca(doubs$env, scale = TRUE, scan = FALSE, nf = 3)
 #' nic1 <- niche(dudi1, doubs$fish, scann = FALSE)
@@ -67,7 +68,6 @@
 #' plot_dym_sp(subnic1, "Neba")
 #' @importFrom graphics par layout arrows points legend polygon abline text
 #' @importFrom wordcloud textplot
-#' @importFrom SIBER siberConvexhull
 plot_dym_sp <- function(subnic, sp, xlab=NULL, ylab=NULL, main=NA, col.axis="azure3", lty.axis=2, lwd.axis=2,
                         border.E="black",
                         col.E="#92c5de",
@@ -96,7 +96,7 @@ plot_dym_sp <- function(subnic, sp, xlab=NULL, ylab=NULL, main=NA, col.axis="azu
                         cex.SR.pos=1,
                         col.arrow="black",
                         angle.arrow=20,
-                        lwd.arrow=2, length.arrow=0.1, font.sp=2, leg=T, posi.leg="topleft", bty.leg="n", ...){
+                        lwd.arrow=2, length.arrow=0.1, font.sp=2, leg=TRUE, posi.leg="topleft", bty.leg="n", ...){
 
 
 fac <- subnic$factor
