@@ -27,13 +27,14 @@
 #' @param pt.su  point color contour if pch=21:25.
 #' @param cex.su size of the points representing the sampling units (SU), see \link[graphics]{points} for more details.
 #' @param pch.su type of the points representing the sampling units (SU), see \link[graphics]{points} for more details.
-#' @param leg a logical option for legend to be plotted or not, default leg=T.
+#' @param leg a logical option for legend to be plotted or not, default leg=TRUE.
 #' @param posi.leg legend location in the graph, see \link[graphics]{legend} for more details.
 #' @param bty.leg the type of box to be drawn around the legends. The allowed values are "o" (the default) and "n". See \link[graphics]{legend} for more details
 #' @param ...	further arguments passed to or from other methods.
 
 #' @examples
 #' library(subniche)
+#' library(ade4)
 #' data(doubs)
 #' dudi1 <- dudi.pca(doubs$env, scale = TRUE, scan = FALSE, nf = 3)
 #' nic1 <- niche(dudi1, doubs$fish, scann = FALSE)
@@ -50,7 +51,7 @@
 #' @export subplot_K
 #' @importFrom graphics par layout arrows points legend polygon abline
 #' @importFrom wordcloud textplot
-#' @importFrom SIBER siberConvexhull
+#' @importFrom grDevices chull
 #'
 #'
 subplot_K <- function(subnic, main=NULL, xlab=NULL, ylab=NULL, col.axis="azure3", lty.axis=2, lwd.axis=2,
@@ -73,7 +74,7 @@ subplot_K <- function(subnic, main=NULL, xlab=NULL, ylab=NULL, col.axis="azure3"
                       pt.su="black",
                       cex.su=0.7,
                       pch.su=1,
-                      leg=T,
+                      leg=TRUE,
                       posi.leg="topleft",
                       bty.leg="n", ...){
   fac <- subnic$factor
@@ -85,12 +86,12 @@ subplot_K <- function(subnic, main=NULL, xlab=NULL, ylab=NULL, col.axis="azure3"
     ylab=paste(paste("OMI2",eig[2], sep=" "),"%",sep="")}
   N <- length(lev)
   plot(subnic$ls, main=main, xlab=xlab, ylab=ylab, type="n",...)
-  E <- siberConvexhull(subnic$ls[,1], subnic$ls[,2])
+  E <- convexhull(subnic$ls[,1], subnic$ls[,2])
   polygon(E$xcoords,E$ycoords, border=border.E, col=col.E, lty=lty.E, lwd=lwd.E)
   for (i in 1:N){
     subnici <- subnic$ls[which(fac==lev[i]),]
     G_k <- subnic$G_k[grep(lev[i],rownames(subnic$G_k)),]
-    K <- siberConvexhull(subnici[,1], subnici[,2])
+    K <- convexhull(subnici[,1], subnici[,2])
     polygon(K$xcoords,K$ycoords, border=border.K, col=col.K, lty=lty.K, lwd=lwd.K)
     points(subnici,cex=cex.su, col=pt.su, bg=col.su, pch=pch.su)
     points(G_k[,1], G_k[,2], col=col.Gk.pt, bg=col.Gk.pos, pch=pch.Gk.pos, cex= cex.Gk.pos)
